import 'package:flutter/material.dart';
import 'package:xinlake_text/validator.dart' as validator;

class ValidatorDemo extends StatefulWidget {
  const ValidatorDemo({Key? key}) : super(key: key);

  @override
  State<ValidatorDemo> createState() => _ValidatorState();
}

class _ValidatorState extends State<ValidatorDemo> {
  static const String _invalidInput = "Invalid input";
  static const InputDecoration _decoration = InputDecoration(
    contentPadding: EdgeInsets.only(top: 8, bottom: 4),
  );

  @override
  Widget build(BuildContext context) {
    return SingleChildScrollView(
      padding: const EdgeInsets.all(10),
      child: Column(
        children: [
          Row(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("Length 4 ~ 8")),
                  validator: (value) => validator.isLength(value, 4, 8) ? null : _invalidInput,
                ),
              ),
              const SizedBox(width: 10),
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("Letters (a~z, A~Z)")),
                  validator: (value) => validator.isAlpha(value) ? null : _invalidInput,
                ),
              ),
              const SizedBox(width: 10),
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("Numbers")),
                  validator: (value) => validator.isNumeric(value) ? null : _invalidInput,
                ),
              ),
              const SizedBox(width: 10),
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("Letters, Numbers")),
                  validator: (value) => validator.isAlphanumeric(value) ? null : _invalidInput,
                ),
              ),
            ],
          ),
          Row(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("ASCII")),
                  validator: (value) => validator.isAscii(value) ? null : _invalidInput,
                ),
              ),
              const SizedBox(width: 10),
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("Multibyte")),
                  validator: (value) => validator.isMultibyte(value) ? null : _invalidInput,
                ),
              ),
            ],
          ),
          Row(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("Hexadecimal")),
                  validator: (value) => validator.isHexadecimal(value) ? null : _invalidInput,
                ),
              ),
              const SizedBox(width: 10),
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("Hex color")),
                  validator: (value) => validator.isHexColor(value) ? null : _invalidInput,
                ),
              ),
            ],
          ),
          Row(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("IP")),
                  validator: (value) => validator.isIP(value) ? null : _invalidInput,
                ),
              ),
              const SizedBox(width: 10),
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("Port number")),
                  validator: (value) => validator.isPortNumber(value) ? null : _invalidInput,
                ),
              ),
            ],
          ),
          Row(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("FQDN")),
                  validator: (value) => validator.isFQDN(value) ? null : _invalidInput,
                ),
              ),
              const SizedBox(width: 10),
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("URL")),
                  validator: (value) => validator.isURL(value) ? null : _invalidInput,
                ),
              ),
              const SizedBox(width: 10),
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("Email")),
                  validator: (value) => validator.isEmail(value) ? null : _invalidInput,
                ),
              ),
            ],
          ),
          Row(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("Base64")),
                  validator: (value) => validator.isBase64(value) ? null : _invalidInput,
                ),
              ),
              const SizedBox(width: 10),
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("UUID")),
                  validator: (value) => validator.isUUID(value) ? null : _invalidInput,
                ),
              ),
            ],
          ),
          Row(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("Credit card")),
                  validator: (value) => validator.isCreditCard(value) ? null : _invalidInput,
                ),
              ),
              const SizedBox(width: 10),
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("ISBN")),
                  validator: (value) => validator.isISBN(value) ? null : _invalidInput,
                ),
              ),
              const SizedBox(width: 10),
              Expanded(
                child: TextFormField(
                  autovalidateMode: AutovalidateMode.always,
                  decoration: _decoration.copyWith(label: const Text("Postal code")),
                  validator: (value) => validator.isPostalCode(value, "CN") ? null : _invalidInput,
                ),
              ),
            ],
          ),
        ],
      ),
    );
  }
}
